import request from '@/utils/request'

// 查询数据源列表
export function listDatabase(query) {
  return request({
    url: '/system/base/database/list',
    method: 'get',
    params: query
  })
}

// 查询数据源下的数据表列表
export function listTable(databaseId) {
  return request({
    url: '/system/base/database/table/list',
    method: 'get',
    params: { databaseId }
  })
}

// 查询数据源下的数据表列表
export function listColumn(tableId) {
  return request({
    url: '/system/base/database/column/list',
    method: 'get',
    params: { tableId }
  })
}

// 查询数据源详细
export function getDatabase(id) {
  return request({
    url: '/system/base/database/' + id,
    method: 'get'
  })
}

// 同步
export function syncDatabase(id) {
  return request({
    url: '/system/base/database/sync',
    method: 'post',
    data: {
      id
    }
  })
}

// 同步到数据
export function syncToData(id) {
  return request({
    url: '/system/integration/data/sync',
    method: 'post',
    data: {
      id
    }
  })
}

// 新增数据源
export function addDatabase(data) {
  return request({
    url: '/system/base/database',
    method: 'post',
    data: data
  })
}

// 修改数据源
export function updateDatabase(data) {
  return request({
    url: '/system/base/database',
    method: 'put',
    data: data
  })
}

// 删除数据源
export function delDatabase(id) {
  return request({
    url: '/system/base/database/' + id,
    method: 'delete'
  })
}
